@@ -2,12 +2,12 @@ package Plack::Middleware::CookieMonster;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 $VERSION = eval $VERSION;
 
 use parent qw/ Plack::Middleware /;
 
-use Plack::Util::Accessor qw( cookie_names );
+use Plack::Util::Accessor qw( cookie_names path );
 use Plack::Request;
 
 
@@ -18,8 +18,13 @@ sub call {
 
     if ( $env->{ 'plack.stacktrace.html' } && $res->[ 0 ] == 500 ) {
         my @cookies = $self->_get_cookie_names( $env );
+        my $path = '';
+        if ( defined $self->path ) {
+            $path = sprintf 'path=%s; ', $self->path; 
+        }
+        my $fmt = sprintf '%%s=deleted; %sExpires=Sat, 01-May-1971 04:30:01 GMT', $path;
         foreach my $cookie ( @cookies ) {
-            push @{ $res->[ 1 ] }, 'Set-Cookie', sprintf '%s=deleted; Expires=Sat, 01-May-1971 04:30:01 GMT', $cookie;
+            push @{ $res->[ 1 ] }, 'Set-Cookie', sprintf $fmt, $cookie;
         }
     }
 
@@ -53,6 +58,9 @@ Plack::Middleware::CookieMonster - Eats all your (session) cookies in case Plack
  enable 'CookieMonster', cookies_names => [ 'session_cookie', 'foobar_cookie' ];
  enable 'StackTrace';
 
+ # Only expire selected cookies on a certain path
+ enable 'CookieMonster', cookies_names => [ 'session_cookie', 'foobar_cookie' ], path => '/foo';
+ enable 'StackTrace';
 
  # Expire all cookies the browser sent
  enable 'CookieMonster';
@@ -64,7 +72,7 @@ When developing a plack application with Plack::Middleware::StackTrace enabled,
 you may sometimes find yourself in a situation where your current session for
 your webapp is borked. Your app would usually clear any session cookies in that
 case, but since Plack::Middleware::StackTrace will simply throw away any HTTP
-headers you set, you'll be stuck to that session.
+headers your app sends, you'll be stuck to that session.
 
 C<Plack::Middleware::CookieMonster> will detect that C<Plack::Middleware::StackTrace>
 rendered a stack trace and will add C<Set-Cookie> headers to the response so that
@@ -75,10 +83,21 @@ control in my browser and because I think we should automate as much as possible
 
 =head1 CONFIGURATION
 
+=over
+
+=item cookie_names
+
 You can provide a C<cookie_names> parameter, pointing to an array-ref containing
 the names of all the cookies you want to clear. Otherwise, all cookies the browser
 sent will be expired.
 
+=item path
+
+If your session cookie comes with a path parameter, configure this middleware to
+expire the cookie(s) on that path. Otherwise, confusion will rule.
+
+=back
+
 =head1 AUTHOR
 
 Manni Heumann
